<?php

/* ----------------------------------------------------------------------------------------------------------------
WARNING: Modifying the following code is strictly prohibited per the terms of your agreement with Clickcentive.com,
and any of its affiliate partners.  Failure to comply with the terms of agreement will result in the immediate 
termination of your account, and the forfeiture of any credits and/or commissions in your account.
---------------------------------------------------------------------------------------------------------------- */	
	
class ClickCentiveAdmin extends ClickCentive
{	
	function ClickCentiveAdmin() 
	{
		$this->_construct();
	}
		
	protected function _construct() 
	{
		$this->registerActions();
	}
	
	
	/*
	 * Registers WP Action and Filter Hooks
	 * @return null
	*/  	
	protected function registerActions()
	{
		register_activation_hook(CLICKCENTIVE_DIR . 'cc.in.php', array(&$this, 'activate_plugin'));
		register_deactivation_hook(CLICKCENTIVE_DIR . 'cc.in.php', array(&$this, 'deactivate_plugin'));

		add_action('transition_post_status', array(&$this, 'post_updated'), 10, 3);
		add_action('create_category', array(&$this, 'category_updated'));
		add_action('edit_category',   array(&$this, 'category_updated'));
		add_action('delete_category', array(&$this, 'category_deleted'));	

		$table_name = $GLOBALS['wpdb']->prefix.'clickcentive';
		if($GLOBALS['wpdb']->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
			add_action('admin_notices', array(&$this, 'dbError'));
		}
	}

	/*
	 * Notifies User That Plugin DB Was Not Correctly Installed
	 * @return null
	*/ 	
	public function dbError()
	{
		echo '<div id="my_admin_notice" class="updated fade">';
		echo '<p><strong>ClickCentive Plugin Notice:<br/><br/></strong>';
		echo 'The ClickCentive Plugin database does not exist.  Please de-activate, and then re-activate the plugin to install the database.<br/>';
		echo '</p></div>';	
	}
	
	
	/*
	 * Runs on Plugin Activation
	 * Installs Plugin DB Tables
	 * Updates Option Records
	 * Sends Posts To Content Repository
	 * @return null
	*/  	
	public function activate_plugin()
	{
		global $wpdb;
		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

		$sql = "CREATE TABLE " . $wpdb->prefix . 'clickcentive' . " (
				id INT(11) NOT NULL AUTO_INCREMENT,
				link_id INT(11) NOT NULL,
				post_id INT(11) NOT NULL,
				keyword VARCHAR(255) NOT NULL,
				target VARCHAR(255) NOT NULL,
				hits INT(11) UNSIGNED NOT NULL,
				created DATETIME NOT NULL,
				modified DATETIME NOT NULL,				
				UNIQUE KEY id (id)	
				)";
				
		dbDelta( $sql );
		
		$blog_id = $this->getBlogID();
		$security_key = md5('cc_' . microtime(true) . $blog_id);
		
		update_option('clickcentive_version', CLICKCENTIVE_VERSION);
		update_option('clickcentive_security_key', $security_key);
		
		$success = $this->sendData('ActivatePlugin', array( 
			'Posts'      => $this->getPosts(), 
			'Categories' => $this->getCategories(), 
			'Tags'       => $this->getTags() 
			));
	}	

	
	/*
	 * Runs on Plugin Deactivation
	 * Notifies Content Repository
	 * @return null
	*/  	
	public function deactivate_plugin()
	{
		$this->sendData('DeactivatePlugin');
	}
	
	
	/*
	 * Notifies Content Repository When Post Is Created, Updated, or Deleted
	 * @return null
	*/  	
	public function post_updated($new_status, $old_status, $post_object)
	{
		if($new_status == 'publish' || ($old_status == 'publish' && $new_status != 'publish') ) 
		{
			if(!$post = $this->getPosts($post_object->ID))
			return false;
		
			if($old_status == 'publish' && $new_status != 'publish')
			$post[0]['status'] = 'inactive';
			
			$this->sendData('PostsProcess', array('Posts' => $post));
		}
	}
	
	
	/*
	 * Notifies Content Repository When Category Is Created, or Updated
	 * @return null
	*/  	
	public function category_updated($catID)
	{
		$this->sendData('CategoriesProcess', array('Categories' => $this->getCategories($catID)));	
	}
	
	
	/*
	 * Notifies Content Repository When Category Is Deleted
	 * @return null
	*/  	
	public function category_deleted($catID)
	{
		$this->sendData('DeleteCategory', array('Category' => $catID));
	}	

}

$CC_Admin = new ClickCentiveAdmin();

?>