<?php

/* ----------------------------------------------------------------------------------------------------------------
WARNING: Modifying the following code is strictly prohibited per the terms of your agreement with Clickcentive.com,
and any of its affiliate partners.  Failure to comply with the terms of agreement will result in the immediate 
termination of your account, and the forfeiture of any credits and/or commissions in your account.
---------------------------------------------------------------------------------------------------------------- */	
	
class ClickCentive
{	
	/*
	 * Generates Blog ID Hash Based On Blog URL
	 * @return string
	*/  	
	protected function getBlogID()
	{
		global $wpdb;
		if(!$site_url = $wpdb->get_var("SELECT option_value FROM {$wpdb->prefix}options WHERE option_name = 'siteurl'"))
		$site_url = site_url();
		
		$site_url = trim($site_url,'/');
			
		return md5($site_url);
	}	


	/*
	 * Sends Data To Content Repository
	 * @return boolean
	*/  	
	public function sendData($action, $data = array())
	{
		require_once CLICKCENTIVE_DIR . 'cc.ns.php';
		if(!class_exists('nusoap_client')) return $this->logError('Unable To Load NuSoap.');

		$url = 'http://clickcentive.com/hssrvrapp_v3201.php?wsdl';
		
		$client = new nusoap_client($url, 'wsdl');
		
		$blog_id = $this->getBlogID();

		if(!$security_key = get_option('clickcentive_security_key')) {
			$security_key = md5('cc_' . microtime(true) . $blog_id);
			update_option('clickcentive_security_key', $security_key);
		}
		
		$data['Request'] = array(
			'uniqueid'     => $this->getBlogID(), 
			'blogurl'      => site_url(), 
			'userkey'      => CLICKCENTIVE_USER_ID,
			'security_key' => $security_key
		);
		
		$success = $client->call($action, $data);

		return $client->getError() ? $this->logError($client->getError()) : $success;
	}

	
	/*
	 * Retrieves Blog Posts
	 * @return boolean
	*/  	
	public function getPosts($postID = null)
	{
		global $wpdb;
		$query = "
			SELECT * FROM $wpdb->posts 
			WHERE post_type IN ('post','page') 
			AND " . ( $postID !== null ? "ID = '$postID'" : "post_status = 'publish'" ) . " 
			ORDER BY post_date DESC";
		
		if(!$posts = $wpdb->get_results($query)) {
			return $this->logError('Unable To Retrieve Post(s).');
		}
		
		$i = 0;
		$data = array();
		foreach($posts as $post)
		{		
			if($postID == null && strlen(strip_tags($post->post_content)) < 200) continue;
		
			$data[$i]['postid']      = $post->ID;
			$data[$i]['pu']     	 = $post->guid;
			$data[$i]['title']   	 = $post->post_title;
			$data[$i]['content'] 	 = $post->post_content;					
			$data[$i]['publish_dt']  = $post->post_date;
			$data[$i]['modified_dt'] = $post->post_modified;
			$data[$i]['status']  	 = $post->post_status;
			$data[$i]['author']  	 = get_userdata($post->post_author)->nickname;
			$data[$i]['tags'] 		 = array();
			$data[$i]['categories']  = array();
			$data[$i]['comments']    = array();			
		
			if($categories = get_the_category($post->ID)) {
				foreach($categories as $cat) {
					$data[$i]['categories'][] = array('id' => $cat->cat_ID, 'name' => $cat->cat_name);
				}
			}	
			if($tags = get_the_tags($post->ID)) {
				foreach($tags as $tag) {
					$data[$i]['tags'][] = array('id' => $tag->term_id, 'name' => $tag->name);
				}
			}
			if($comments = get_comments('status=approve&$post_id='.$post->ID) ) {
 				foreach($comments as $comment) {
					$data[$i]['comments'][] = array('id' => $comment->comment_ID, 'content' =>  $comment->comment_content);
				}					
			}
					
			$i++;
		}
		
		return $data;
	}
	
	/*
	 * Retrieves Categories
	 * @return boolean
	*/  	
	public function getCategories($id = null)
	{
		if(!$categories = get_categories('hide_empty=0'.( $id !== null ? "&include=$id" : '')))
		return false;

		$data = array();
		foreach($categories as $category) {
			$data[] = array('id' => $category->cat_ID, 'name' => $category->cat_name);
		}
		return $data;	
	}
	
	
	/*
	 * Retrieves Post Tags
	 * @return boolean
	*/  	
	public function getTags()
	{
		if(!$tags = get_tags('hide_empty=1'))
		return false;

		$data = array();
		foreach( $tags as $tag ) {
			$data[] = array('id' => $tag->term_id, 'name' => $tag->name);
		}
		return $data;		
	}	

	
	
	/*
	 * Processes Link Update Requests
	 * @return string
	*/  	
	public function ProcessLinks($action = 'RemoveLinks', $links = array()) 
	{	
		global $wpdb;
		
		$result = array('completed' => array(), 'failed' => array());
		
		foreach($links as $key => $link)
		{
			$vars = explode('###',$link['link']);
			$timestamp = date('Y-m-d H:i:s');
			
			if($action == 'InsertLinks') 
			{
				if(!$post = get_post($link['postid'])) {
					$result['failed'][] = $link + array('error' => 'Unable to Find Requested Post');
					continue;
				}	

				$keyword = trim($link['keyword']);
				
				$encoded = stripslashes(preg_replace("/(<[^>]*>)/ie","str_replace(' ','%_WS_%','$1')", $post->post_content));
				$encoded = stripslashes(preg_replace("/(<[^>]*href=[^>]*>)([^<]+)(<[^>]*>)/ie","str_replace(' ','%_WS_%','$1%_LI_%$2%_LI_%$3')", $encoded));
				
				$search  = "/(^|[^a-zA-Z0-9\"\'@\$\%\/\+\-\_\#\=\@\&]){1}($keyword)([^a-zA-Z0-9\"\'\%\/\+\-\_\#\=\@\&]|$){1}/i";
				$replace = "$1__TAKEN__$3";
						
				if($existing = $wpdb->get_var("SELECT COUNT(*) as existing FROM {$wpdb->prefix}clickcentive WHERE post_id = 74 AND keyword = '$keyword'"))	{
					for($r = 1; $r <= $existing; $r++) {
						$encoded = preg_replace($search, $replace, $encoded, 1);
					}		
				}
				
				$encoded = preg_replace($search, $replace, $encoded, 1, $count);
				
				if($count != 1) {
					$result['failed'][] = $link + array('error' => 'No Keyword Matches Found For Link');
					continue;
				}
		
				$link_id = abs($vars[0]);
				$keyword = $wpdb->escape($keyword);
				$target  = $wpdb->escape($vars[1]);
				
				$insert = $wpdb->query("
					INSERT INTO {$wpdb->prefix}clickcentive
					(link_id, post_id, keyword, target, created, modified)
					VALUES ('$link_id', '{$post->ID}', '$keyword', '$target', '$timestamp', '$timestamp')
					");
					
				if(!$insert) {
					$result['failed'][] = $link + array('error' => 'Database Update Failed', 'db_query' => $wpdb->last_query);
					continue;					
				}
				
				$result['completed'][] = $link;
			}	
			if($action == 'UpdateLinks') 
			{
				if(!$post = get_post($link['postid'])) {
					$result['failed'][] = $link + array('error' => 'Unable to Find Requested Post');
					continue;
				}	

				$link_id = abs($vars[0]);
				if(!$db_link = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}clickcentive WHERE link_id = '$link_id '")) {
					$result['failed'][] = $link + array('error' => 'Unable to Find Requested Link');
					continue;
				}	
				
				$target = $wpdb->escape($vars[2]);
				$update = $wpdb->query("
					UPDATE {$wpdb->prefix}clickcentive 
					SET target = '$target', modified = '$timestamp' WHERE link_id = '$link_id'
					");
					
				if(!$update) {
					$result['failed'][] = $link + array('error' => 'Database Update Failed', 'db_query' => $wpdb->last_query);
					continue;					
				}					
				
				$result['completed'][] = $link;
			}
			if($action == 'RemoveLinks') 
			{
				$link_id = abs($vars[0]);
				
				if(!$db_link = $wpdb->get_row("SELECT * FROM {$wpdb->prefix}clickcentive WHERE link_id = '$link_id '")) {
					$result['completed'][] = $link;
					continue;
				}

				$removed = $wpdb->query("DELETE FROM {$wpdb->prefix}clickcentive WHERE link_id = '$link_id'");
					
				if(!$removed) {
					$result['failed'][] = $link + array('error' => 'Database Update Failed', 'db_query' => $wpdb->last_query);
					continue;					
				}
				
				$result['completed'][] = $link;
			}			
		}

		return $result;
	}

	
	/*
	 * Stores Error Message
	 * @return boolean false
	*/  
	protected function logError($error = '')
	{
		$file_dir = CLICKCENTIVE_DIR . 'log.txt';
		$log_type = file_exists($file_dir) ? (filesize($file_dir) > 5000 ? 'w' : 'a') : 'w';
			
		$error = date('D, d M Y H:i:s') . " - $error\n";
			
		if($fh = fopen($file_dir, $log_type)) {
			fwrite($fh, $error );	
			fclose($fh);
		}	
	}

}

?>